==> qtjambi-serialbus-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiSerialBus/QModbusClient_shell.h <==
#ifndef QMODBUSCLIENT_SHELL_H
#define QMODBUSCLIENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSerialBus/qmodbusclient.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbusdevice.h>
#include <QtSerialBus/qmodbuspdu.h>
#include <QtSerialBus/qmodbusreply.h>
#include <QtJambi/RegistryAPI>


class QModbusClient_shell : public QModbusClient, public QtJambiShellInterface
{
public:
    QModbusClient_shell(QObject* parent0 = nullptr);
    ~QModbusClient_shell() override;

    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool open() override;
    bool processPrivateResponse(const QModbusResponse& response0, QModbusDataUnit* data1) override;
    bool processResponse(const QModbusResponse& response0, QModbusDataUnit* data1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QModbusClient_access : public QModbusClient
{
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_processPrivateResponse_cref_QModbusResponse_QModbusDataUnit_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID response0, QtJambiNativeID data1);
    jboolean __qt_processResponse_cref_QModbusResponse_QModbusDataUnit_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID response0, QtJambiNativeID data1);
};

#endif // QMODBUSCLIENT_SHELL_H

==> qtjambi-serialbus-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiSerialBus/QModbusClient_shell.h <==
#ifndef QMODBUSCLIENT_SHELL_H
#define QMODBUSCLIENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSerialBus/qmodbusclient.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSerialBus/qmodbusdataunit.h>
#include <QtSerialBus/qmodbusdevice.h>
#include <QtSerialBus/qmodbuspdu.h>
#include <QtSerialBus/qmodbusreply.h>
#include <QtJambi/RegistryAPI>


class QModbusClient_shell : public QModbusClient, public QtJambiShellInterface
{
public:
    QModbusClient_shell(QObject* parent0 = nullptr);
    ~QModbusClient_shell() override;

    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool open() override;
    bool processPrivateResponse(const QModbusResponse& response0, QModbusDataUnit* data1) override;
    bool processResponse(const QModbusResponse& response0, QModbusDataUnit* data1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QModbusClient_access : public QModbusClient
{
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_open(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_processPrivateResponse_cref_QModbusResponse_QModbusDataUnit_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID response0, QtJambiNativeID data1);
    jboolean __qt_processResponse_cref_QModbusResponse_QModbusDataUnit_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID response0, QtJambiNativeID data1);
};

#endif // QMODBUSCLIENT_SHELL_H
